@@ -26,6 +26,7 @@ BEGIN {
             my $self = $_[0];
             my ($callback_next, $callback_previous) = @{ $self->{param} };
             my ($min, $min_open) = $self->{parent}->min_a;
+            # my ($max, $max_open) = $self->{parent}->max_a;
 
             my ( $min1, $min2 );
             $min1 = $callback_next->( $min );
@@ -51,6 +52,7 @@ BEGIN {
 
             return ( $self->new( $min1 ),
                      $self->new( $start, $end )->
+                     # $self->new( {a => $start, b => $end, open_end => $max_open} )->
                           _function( '_recurrence', @{ $self->{param} } ) );
         };
     $Set::Infinite::_last{_recurrence} =
@@ -198,6 +200,35 @@ sub _is_recurrence
     $_[0]->{parent}->is_forever
 }
 
+sub intersects
+{
+    my ($s1, $s2) = (shift,shift);
+
+    if ( exists $s1->{method} && $s1->{method} eq '_recurrence' )
+    {
+        # recurrence && span
+        unless ( ref($s2) && exists $s2->{method} ) {
+            my $intersection = $s1->intersection($s2, @_);
+            my $min = $intersection->min;
+            return 1 if defined $min && $min != NEG_INFINITY && $min != INFINITY;
+            my $max = $intersection->max;
+            return 1 if defined $max && $max != NEG_INFINITY && $max != INFINITY;
+        }
+
+        # recurrence && recurrence
+        if ( $s1->{parent}->is_forever && 
+            ref($s2) && _is_recurrence( $s2 ) )
+        {
+            my $intersection = $s1->intersection($s2, @_);
+            my $min = $intersection->min;
+            return 1 if defined $min && $min != NEG_INFINITY && $min != INFINITY;
+            my $max = $intersection->max;
+            return 1 if defined $max && $max != NEG_INFINITY && $max != INFINITY;
+        }
+    }
+    return $s1->SUPER::intersects( $s2, @_ );
+}
+
 sub intersection
 {
     my ($s1, $s2) = (shift,shift);
@@ -299,7 +330,7 @@ Creates a recurrence set. The set is defined inside a 'base set'.
    $recurrence = $base_set->_recurrence ( \&next, \&previous );
 
 The recurrence functions take one argument, and return the 'next' or 
-the 'previous' occurence. 
+the 'previous' occurrence. 
 
 Example: defines the set of all 'integer numbers':
 
@@ -330,17 +361,17 @@ Example: defines the set of all 'integer numbers':
 
     {
         my $x = 234.567;
-        print "next occurence after $x = ", 
+        print "next occurrence after $x = ",
               $recurrence->{param}[0]->( $x ), "\n";  # 235
-        print "previous occurence before $x = ",
+        print "previous occurrence before $x = ",
               $recurrence->{param}[2]->( $x ), "\n";  # 234
     }
 
     {
         my $x = 234;
-        print "next occurence after $x = ",
+        print "next occurrence after $x = ",
               $recurrence->{param}[0]->( $x ), "\n";  # 235
-        print "previous occurence before $x = ",
+        print "previous occurrence before $x = ",
               $recurrence->{param}[2]->( $x ), "\n";  # 233
     }
 
@@ -378,7 +409,7 @@ Please report bugs using rt.cpan.org
 
 =head1 AUTHOR
 
-Flavio Soibelmann Glock <fglock@pucrs.br>
+Flavio Soibelmann Glock <fglock@gmail.com>
 
 The recurrence generation algorithm is based on an idea from Dave Rolsky.
 
